//
//  BCViewController.m
//  Big Clock
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "BCViewController.h"

@interface BCViewController ()
@property (weak, nonatomic) IBOutlet UIImageView *baseImageView;
@property (weak, nonatomic) IBOutlet UIImageView *hourImageView;
@property (weak, nonatomic) IBOutlet UIImageView *minImageView;
@property (weak, nonatomic) IBOutlet UIImageView *secImageView;
@property (weak, nonatomic) IBOutlet UILabel *digitalLabel;
@property (weak, nonatomic) IBOutlet UIImageView *backgroundView;

@end

@implementation BCViewController {
    NSTimer *timer;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.

    timer = [NSTimer scheduledTimerWithTimeInterval:1.0
                                             target:self
                                           selector:@selector(timerProc:)
                                           userInfo:nil
                                            repeats:YES];
    
    [self addMotionEffectForView:self.backgroundView depth:30.0];
}

- (void)addMotionEffectForView:(UIView *)aView depth:(CGFloat)depth
{
    UIInterpolatingMotionEffect *effectX = [[UIInterpolatingMotionEffect alloc] initWithKeyPath:@"center.x"
                                                                                           type:UIInterpolatingMotionEffectTypeTiltAlongHorizontalAxis];
    UIInterpolatingMotionEffect *effectY = [[UIInterpolatingMotionEffect alloc] initWithKeyPath:@"center.y"
                                                                                           type:UIInterpolatingMotionEffectTypeTiltAlongVerticalAxis];
    
    
	effectX.minimumRelativeValue = @(depth);
	effectX.maximumRelativeValue = @(-depth);
	effectY.minimumRelativeValue = @(depth);
	effectY.maximumRelativeValue = @(-depth);
    
	[aView addMotionEffect:effectX];
	[aView addMotionEffect:effectY];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)timerProc:(NSTimer *)timer
{
    NSDate *date = [NSDate date];
    
    NSCalendar *cal = [NSCalendar currentCalendar];
    NSDateComponents *components =
    [cal components:(NSHourCalendarUnit | NSMinuteCalendarUnit | NSSecondCalendarUnit)
           fromDate:date];
    int hour = components.hour % 12;
    int min = components.minute;
    int sec = components.second;
    
    float secAngle = (M_PI*2)/60*sec;
    float minAngle = (M_PI*2)/60*min + secAngle/60;
    float hourAngle = (M_PI*2)/12*hour + minAngle/12;
    
    [UIView beginAnimations:nil context:nil];
    [UIView setAnimationDuration:0.5];

    self.hourImageView.transform = CGAffineTransformMakeRotation(hourAngle);
    self.minImageView.transform = CGAffineTransformMakeRotation(minAngle);
    self.secImageView.transform = CGAffineTransformMakeRotation(secAngle);

    [UIView commitAnimations];
    
    self.digitalLabel.text =
        [NSString stringWithFormat:@"%d:%02d:%02d", hour, min, sec];
}

@end
