//
//  DMDetailViewController.m
//  Daily Memo
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "DMDetailViewController.h"

@interface DMDetailViewController ()
@property (weak, nonatomic) IBOutlet UITextField *titleField;
@property (weak, nonatomic) IBOutlet UITextView *textView;
@property (weak, nonatomic) IBOutlet NSLayoutConstraint *bottomConstraint;
- (void)configureView;
@end

@implementation DMDetailViewController

#pragma mark - Managing the detail item

- (void)setDetailItem:(id)newDetailItem
{
    if (_detailItem != newDetailItem) {
        _detailItem = newDetailItem;
        
        // Update the view.
        [self configureView];
    }
}

- (void)configureView
{
    // Update the user interface for the detail item.

    if (self.detailItem) {
        NSURL *fileURL = (NSURL *)self.detailItem;
        NSDictionary *dict = [NSDictionary dictionaryWithContentsOfURL:fileURL];
        
        self.titleField.text = dict[@"title"];
        self.textView.text = dict[@"body"];
    }
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    [self configureView];
}

- (void)viewWillAppear:(BOOL)animated
{
    NSNotificationCenter *notifCenter = [NSNotificationCenter defaultCenter];
    [notifCenter addObserver:self selector:@selector(keyboardWillShow:) name:UIKeyboardWillShowNotification object:nil];
    [notifCenter addObserver:self selector:@selector(keyboardWillHide:) name:UIKeyboardWillHideNotification object:nil];
    [notifCenter addObserver:self selector:@selector(changedDynamicTypeSetting:) name:UIContentSizeCategoryDidChangeNotification object:nil];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)saveNotes
{
    NSURL *fileURL = (NSURL *)self.detailItem;
    NSDictionary *dict = @{ @"title": self.titleField.text, @"body": self.textView.text };
    [dict writeToURL:fileURL atomically:YES];
}

- (void)textFieldDidEndEditing:(UITextField *)textField
{
    [self saveNotes];
}

- (void)textViewDidEndEditing:(UITextView *)textView
{
    [self saveNotes];
}

- (void)keyboardWillShow:(NSNotification *)notification
{
    NSDictionary *userInfo = notification.userInfo;
    
    CGRect keyboardFrame = [userInfo[UIKeyboardFrameEndUserInfoKey] CGRectValue];
    NSTimeInterval duration = [userInfo[UIKeyboardAnimationDurationUserInfoKey] doubleValue];
    
    self.bottomConstraint.constant = keyboardFrame.size.height;
    
    [UIView animateWithDuration:duration animations:^{
        [self.view layoutIfNeeded];
    }];
}

- (void)keyboardWillHide:(NSNotification *)notification
{
    NSDictionary *userInfo = notification.userInfo;
    
    NSTimeInterval duration = [userInfo[UIKeyboardAnimationDurationUserInfoKey] doubleValue];
    
    self.bottomConstraint.constant = 0;
    
    [UIView animateWithDuration:duration animations:^{
        [self.view layoutIfNeeded];
    }];
}

- (void)changedDynamicTypeSetting:(NSNotification *)notification
{
    self.titleField.font = [UIFont preferredFontForTextStyle:UIFontTextStyleHeadline];
    self.textView.font = [UIFont preferredFontForTextStyle:UIFontTextStyleBody];
}

@end
