//
//  DMMasterViewController.m
//  Daily Memo
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "DMMasterViewController.h"

#import "DMDetailViewController.h"

@interface DMMasterViewController () {
    NSMutableArray *_objects;
}
@end

@implementation DMMasterViewController

- (void)awakeFromNib
{
    [super awakeFromNib];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    self.navigationItem.leftBarButtonItem = self.editButtonItem;

    UIBarButtonItem *addButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAdd target:self action:@selector(insertNewObject:)];
    self.navigationItem.rightBarButtonItem = addButton;

    _objects = [NSMutableArray array];
}

- (void)viewWillAppear:(BOOL)animated
{
    [_objects removeAllObjects];
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSURL *docDirURL = [fileManager URLForDirectory:NSDocumentDirectory
                                           inDomain:NSUserDomainMask
                                  appropriateForURL:nil
                                             create:NO
                                              error:nil];
    NSArray *files = [fileManager contentsOfDirectoryAtURL:docDirURL
                                includingPropertiesForKeys:@[NSURLContentModificationDateKey]
                                                   options:0
                                                     error:nil];
    [_objects addObjectsFromArray:files];
    
    [_objects sortUsingComparator:^NSComparisonResult(id obj1, id obj2) {
        NSDate *date1, *date2;
        [obj1 getResourceValue:&date1 forKey:NSURLContentModificationDateKey error:nil];
        [obj2 getResourceValue:&date2 forKey:NSURLContentModificationDateKey error:nil];
        return [date2 compare:date1];
    }];
    [self.tableView reloadData];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)insertNewObject:(id)sender
{
    NSDictionary *dict = @{ @"title": @"タイトル", @"body": @"内容" };
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSURL *docDirURL = [fileManager URLForDirectory:NSDocumentDirectory
                                           inDomain:NSUserDomainMask
                                  appropriateForURL:nil
                                             create:NO
                                              error:nil];
    
    NSString *fileName = [[[NSUUID UUID] UUIDString] stringByAppendingPathExtension:@"txt"];
    NSURL *fileURL = [docDirURL URLByAppendingPathComponent:fileName];
    if ([dict writeToURL:fileURL atomically:YES]) {
        [_objects insertObject:fileURL atIndex:0];
        NSIndexPath *indexPath = [NSIndexPath indexPathForRow:0 inSection:0];
        [self.tableView insertRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationAutomatic];
    }
}

#pragma mark - Table View

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return _objects.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"Cell" forIndexPath:indexPath];
    
    NSURL *fileURL = _objects[indexPath.row];
    NSDictionary *dict = [NSDictionary dictionaryWithContentsOfURL:fileURL];
    cell.textLabel.text = dict[@"title"];
    return cell;
}

- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        NSURL *fileURL = _objects[indexPath.row];
        NSFileManager *fileManager = [NSFileManager defaultManager];
        if ([fileManager removeItemAtURL:fileURL error:nil]) {
            [_objects removeObjectAtIndex:indexPath.row];
            [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
        }
    }
}

/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([[segue identifier] isEqualToString:@"showDetail"]) {
        NSIndexPath *indexPath = [self.tableView indexPathForSelectedRow];
        NSURL *fileURL = _objects[indexPath.row];
        [[segue destinationViewController] setDetailItem:fileURL];
    }
    [self.tableView deselectRowAtIndexPath:self.tableView.indexPathForSelectedRow animated:YES];
}

@end
