//
//  NPViewController.m
//  Now Playing
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "NPViewController.h"
#import <MediaPlayer/MediaPlayer.h>
#import <AVFoundation/AVFoundation.h>
#import <Social/Social.h>

@interface NPViewController ()
@property (weak, nonatomic) IBOutlet UIImageView *imageView;
@property (weak, nonatomic) IBOutlet UILabel *titleLabel;
@property (weak, nonatomic) IBOutlet UILabel *artistLabel;

@end

@implementation NPViewController {
    AVSpeechSynthesizer *speechSynth;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    MPMusicPlayerController *playerController = [MPMusicPlayerController iPodMusicPlayer];
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(changedPlayingItem:)
                                                 name:MPMusicPlayerControllerNowPlayingItemDidChangeNotification
                                               object:playerController];
    [playerController beginGeneratingPlaybackNotifications];
    
    speechSynth = [[AVSpeechSynthesizer alloc] init];
}

- (void)changedPlayingItem:(NSNotification *)notification
{
    MPMusicPlayerController *playerController = notification.object;
    MPMediaItem *currentItem = [playerController nowPlayingItem];
    
    NSString *title = [currentItem valueForProperty:MPMediaItemPropertyTitle];
    NSString *artist = [currentItem valueForProperty:MPMediaItemPropertyArtist];
    
    self.titleLabel.text = title;
    self.artistLabel.text = artist;
    
    MPMediaItemArtwork *artwork = [currentItem valueForProperty:MPMediaItemPropertyArtwork];
    UIImage *image = nil;
    if (artwork) {
        image = [artwork imageWithSize:self.imageView.bounds.size];
    }
    if (!image) {
        image = [UIImage imageNamed:@"noartwork"];
    }
    //self.imageView.image = image;
    [UIView transitionWithView:self.imageView
                      duration:0.7
                       options:UIViewAnimationOptionTransitionCrossDissolve
                    animations:^{
                        self.imageView.image = image;
                    }
                    completion:nil];

    AVSpeechUtterance *utter = [AVSpeechUtterance speechUtteranceWithString:title];
    utter.voice = [AVSpeechSynthesisVoice voiceWithLanguage:@"ja-JP"];
    utter.preUtteranceDelay = 2.0;
    [speechSynth stopSpeakingAtBoundary:AVSpeechBoundaryImmediate];
    [speechSynth speakUtterance:utter];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)goToPrev:(id)sender
{
    MPMusicPlayerController *playerController = [MPMusicPlayerController iPodMusicPlayer];
    [playerController skipToPreviousItem];
}

- (IBAction)goToNext:(id)sender
{
    MPMusicPlayerController *playerController = [MPMusicPlayerController iPodMusicPlayer];
    [playerController skipToNextItem];
}

- (IBAction)makeTweet:(id)sender
{
    if (![SLComposeViewController isAvailableForServiceType:SLServiceTypeTwitter]) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"ツイートエラー"
                                                        message:@"利用可能なTwitterアカウントが設定されていません。"
                                                       delegate:nil
                                              cancelButtonTitle:nil
                                              otherButtonTitles:@"OK", nil];
        [alert show];
        return;
    }
    
    MPMusicPlayerController *playerController = [MPMusicPlayerController iPodMusicPlayer];
    MPMediaItem *currentItem = [playerController nowPlayingItem];
    NSString *title = [currentItem valueForProperty:MPMediaItemPropertyTitle];
    NSString *artist = [currentItem valueForProperty:MPMediaItemPropertyArtist];
    NSString *albumTitle = [currentItem valueForProperty:MPMediaItemPropertyAlbumTitle];
    
    NSString *text = @"Now Playing: [Artist]「[Title]」（[Album]）";
    text = [text stringByReplacingOccurrencesOfString:@"[Title]" withString:title];
    text = [text stringByReplacingOccurrencesOfString:@"[Artist]" withString:artist];
    text = [text stringByReplacingOccurrencesOfString:@"[Album]" withString:albumTitle];
    
    SLComposeViewController *controller = [SLComposeViewController composeViewControllerForServiceType:SLServiceTypeTwitter];
    controller.initialText = text;
    controller.completionHandler =^(SLComposeViewControllerResult result){
        [self dismissViewControllerAnimated:YES completion:nil];
    };
    [self presentViewController:controller animated:YES completion:nil];
}

@end
