//
//  MVViewController.m
//  Movie Player
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "MVViewController.h"
#import <MediaPlayer/MediaPlayer.h>

@interface MVViewController ()
@property (weak, nonatomic) IBOutlet UITableView *tableView;

@end

@implementation MVViewController {
    NSArray *fileURLs;
    NSMutableArray      *moviePlayers;
    NSMutableDictionary *thumbnailDict;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSURL *docDirURL = [fileManager URLForDirectory:NSDocumentDirectory
                                           inDomain:NSUserDomainMask
                                  appropriateForURL:nil
                                             create:NO
                                              error:nil];
    
    fileURLs = [fileManager contentsOfDirectoryAtURL:docDirURL
                          includingPropertiesForKeys:nil
                                             options:0
                                               error:nil];
    [self.tableView reloadData];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(fetchedThumbnailImage:)
                                                 name:MPMoviePlayerThumbnailImageRequestDidFinishNotification
                                               object:nil];
    
    thumbnailDict = [NSMutableDictionary dictionary];
    moviePlayers = [NSMutableArray array];
    for (NSURL *fileURL in fileURLs) {
        MPMoviePlayerController *player = [[MPMoviePlayerController alloc] initWithContentURL:fileURL];
        [player requestThumbnailImagesAtTimes:@[ @0.0 ]
                                   timeOption:MPMovieTimeOptionExact];
        [moviePlayers addObject:player];
    }
}

- (void)dealloc
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return fileURLs.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"Movie Item"];
    
    NSURL *fileURL = fileURLs[indexPath.row];
    
    cell.textLabel.text = fileURL.lastPathComponent;
    
    UIImage *image = thumbnailDict[fileURL];
    cell.imageView.image = image;
    
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    NSURL *fileURL = fileURLs[indexPath.row];
    
    MPMoviePlayerViewController *controller = [[MPMoviePlayerViewController alloc] initWithContentURL:fileURL];;
    [self presentMoviePlayerViewControllerAnimated:controller];
}

- (void)fetchedThumbnailImage:(NSNotification *)notification
{
    MPMoviePlayerController *player = notification.object;
    UIImage *image = notification.userInfo[MPMoviePlayerThumbnailImageKey];
    thumbnailDict[player.contentURL] = image;
    
    [moviePlayers removeObject:player];
    
    int index = [fileURLs indexOfObject:player.contentURL];
    NSIndexPath *path = [NSIndexPath indexPathForRow:index
                                           inSection:0];
    [self.tableView reloadRowsAtIndexPaths:@[path]
                          withRowAnimation:UITableViewRowAnimationFade];
}

@end
