//
//  SBMyScene.m
//  Splash Ball
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "SBMyScene.h"
@import CoreMotion;
@import AVFoundation;

@implementation SBMyScene {
    CMMotionManager *motionManager;
    SKEmitterNode *spark;
    NSTimer *sparkTimer;
    NSOperationQueue *soundQueue;
    AVAudioPlayer *soundPlayer;
}

- (void)setupMotionManager
{
    motionManager = [CMMotionManager new];
    motionManager.accelerometerUpdateInterval = 1.0/60;
    [motionManager startAccelerometerUpdatesToQueue:[NSOperationQueue currentQueue]
                                        withHandler:^(CMAccelerometerData *accelerometerData, NSError *error) {
                                            float x = accelerometerData.acceleration.x;
                                            float y = accelerometerData.acceleration.y;
                                            self.physicsWorld.gravity = CGVectorMake(x*10, y*10);
                                        }];
}

- (SKEmitterNode *)loadParticleFromFile:(NSString *)filename
{
    NSURL *fileURL = [[NSBundle mainBundle] URLForResource:filename.stringByDeletingPathExtension
                                             withExtension:@"sks"];
    NSData *fileData = [NSData dataWithContentsOfURL:fileURL];
    return [NSKeyedUnarchiver unarchiveObjectWithData:fileData];
}

- (void)setupParticles
{
    spark = [self loadParticleFromFile:@"MyParticle.sks"];
    spark.particleBirthRate = 0.0;
    spark.particleZPosition = 5.0;
    [self addChild:spark];
}

- (AVAudioPlayer *)loadAudioPlayerFromFile:(NSString *)filename
{
    NSURL *fileURL = [[NSBundle mainBundle] URLForResource:filename.stringByDeletingPathExtension
                                             withExtension:filename.pathExtension];
    AVAudioPlayer *player = [[AVAudioPlayer alloc] initWithContentsOfURL:fileURL error:nil];
    [player prepareToPlay];
    return player;
}

-(id)initWithSize:(CGSize)size
{
    if (self = [super initWithSize:size]) {
        /* Setup your scene here */
        
        self.backgroundColor = [SKColor colorWithRed:0.0 green:0.0 blue:0.0 alpha:1.0];
        self.physicsBody = [SKPhysicsBody bodyWithEdgeLoopFromRect:self.frame];
        self.physicsWorld.contactDelegate = self;
        
        soundQueue = [NSOperationQueue new];
        soundPlayer = [self loadAudioPlayerFromFile:@"sound.aif"];
        
        [self setupParticles];
        [self setupMotionManager];
    }
    return self;
}

- (void)dealloc
{
    [motionManager stopAccelerometerUpdates];
}

-(void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event
{
    /* Called when a touch begins */
    
    for (UITouch *touch in touches) {
        CGPoint location = [touch locationInNode:self];
        
        //SKSpriteNode *sprite = [SKSpriteNode spriteNodeWithImageNamed:@"box"];
        SKSpriteNode *sprite = [SKSpriteNode spriteNodeWithImageNamed:@"circle"];
        sprite.position = location;
        //sprite.physicsBody = [SKPhysicsBody bodyWithRectangleOfSize:sprite.size];
        sprite.physicsBody = [SKPhysicsBody bodyWithCircleOfRadius:sprite.size.width/2];
        sprite.physicsBody.contactTestBitMask = 0x01;
        sprite.physicsBody.friction = 1.0;
        sprite.physicsBody.restitution = 1.0;
        [self addChild:sprite];
    }
}

-(void)update:(CFTimeInterval)currentTime
{
    [self enumerateChildNodesWithName:@"splash" usingBlock:^(SKNode *node, BOOL *stop) {
        CGFloat alpha = node.alpha;
        alpha -= 0.05;
        if (alpha > 0.0) {
            node.alpha = alpha;
        } else {
            [node removeFromParent];
        }
    }];
}

- (void)sparkTimerProc:(NSTimer *)timer
{
    spark.particleBirthRate = 0.0;
}

- (void)sharpenCircle:(SKSpriteNode *)sprite
{
    if (sprite.physicsBody.friction > 0.2) {
        sprite.physicsBody.friction = sprite.physicsBody.friction - 0.1;
    } else {
        [sprite removeFromParent];
        
        SKSpriteNode *splash = [SKSpriteNode spriteNodeWithImageNamed:@"splash"];
        splash.name = @"splash";
        splash.size = CGSizeMake(100, 88);
        splash.zPosition = -5.0;
        splash.position = sprite.position;
        [self addChild:splash];
        
        [soundQueue addOperationWithBlock:^{
            [soundPlayer stop];
            soundPlayer.currentTime = 0.0;
            [soundPlayer play];
        }];
        
        spark.particleBirthRate = 2000;
        spark.position = sprite.position;
        
        if (sparkTimer) {
            [sparkTimer invalidate];
        }
        sparkTimer = [NSTimer scheduledTimerWithTimeInterval:0.2
                                                      target:self
                                                    selector:@selector(sparkTimerProc:)
                                                    userInfo:nil
                                                     repeats:NO];
    }
}

- (void)didBeginContact:(SKPhysicsContact *)contact
{
    if (contact.bodyA.contactTestBitMask & 0x01) {
        SKSpriteNode *sprite = (SKSpriteNode *)contact.bodyA.node;
        [self sharpenCircle:sprite];
    }
    if (contact.bodyB.contactTestBitMask & 0x01) {
        SKSpriteNode *sprite = (SKSpriteNode *)contact.bodyB.node;
        [self sharpenCircle:sprite];
    }
}

@end
