//
//  GNViewController.m
//  Ground Navigator
//
//  Created by numata on 2013/12/05.
//  Copyright (c) 2013年 Satoshi Numata. All rights reserved.
//

#import "GNViewController.h"
@import MapKit;

@interface GNViewController ()
@property (weak, nonatomic) IBOutlet MKMapView *mapView;

@end

@implementation GNViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.mapView.showsUserLocation = YES;
    self.mapView.showsBuildings = YES;
    self.mapView.showsPointsOfInterest = YES;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)showUserLocation:(id)sender
{
    MKUserLocation *location = self.mapView.userLocation;
    
    MKCoordinateRegion region;
    region.center = location.coordinate;
    region.span.latitudeDelta = 0.00126;
    region.span.longitudeDelta = 0.00098;
    
    [self.mapView setRegion:region animated:YES];
}

- (IBAction)shareLocation:(id)sender
{
    MKUserLocation *location = self.mapView.userLocation;
    CLLocationCoordinate2D coord = location.location.coordinate;
    
    NSString *str = [NSString stringWithFormat:
                     @"場所を共有 mymap://%f,%f", coord.latitude, coord.longitude];
    
    UIActivityViewController *controller =
    [[UIActivityViewController alloc] initWithActivityItems:@[str]
                                      applicationActivities:nil];
    [self presentViewController:controller animated:YES completion:nil];
}

- (void)navigateToURL:(NSURL *)mapURL
{
    NSCharacterSet *separator = [NSCharacterSet characterSetWithCharactersInString:@"://,"];
    NSArray *comps = [mapURL.absoluteString componentsSeparatedByCharactersInSet:separator];
    if (comps.count < 5) {
        return;
    }
    
    double latitude = [comps[3] doubleValue];
    double longtitude = [comps[4] doubleValue];
    CLLocationCoordinate2D destCoord = CLLocationCoordinate2DMake(latitude, longtitude);
    
    MKCircle *circle = [MKCircle circleWithCenterCoordinate:destCoord radius:3.0];
    [self.mapView removeOverlays:self.mapView.overlays];
    [self.mapView addOverlay:circle level:MKOverlayLevelAboveRoads];
    [self.mapView setCenterCoordinate:destCoord animated:YES];
    
    [self requestNavigationToDestinationCoord:destCoord];
}

- (void)requestNavigationToDestinationCoord:(CLLocationCoordinate2D)destCoord
{
    CLLocationCoordinate2D sourceCoord = self.mapView.userLocation.location.coordinate;
    
    MKPlacemark *sourcePlacemark = [[MKPlacemark alloc] initWithCoordinate:sourceCoord addressDictionary:nil];
    MKPlacemark *destPlacemark = [[MKPlacemark alloc] initWithCoordinate:destCoord addressDictionary:nil];
    
    MKDirectionsRequest *request = [MKDirectionsRequest new];
    request.transportType = MKDirectionsTransportTypeWalking;
    request.source = [[MKMapItem alloc] initWithPlacemark:sourcePlacemark];
    request.destination = [[MKMapItem alloc] initWithPlacemark:destPlacemark];
    
    MKDirections *directions = [[MKDirections alloc] initWithRequest:request];
    [directions calculateDirectionsWithCompletionHandler:^(MKDirectionsResponse *response, NSError *error) {
        double midLat = (sourceCoord.latitude + destCoord.latitude) / 2.0;
        double midLong = (sourceCoord.longitude + destCoord.longitude) / 2.0;
        
        CLLocationCoordinate2D midCoord = CLLocationCoordinate2DMake(midLat, midLong);
        CLLocation *sourceLoc = [[CLLocation alloc] initWithLatitude:sourceCoord.latitude
                                                           longitude:sourceCoord.longitude];
        CLLocation *destLoc = [[CLLocation alloc] initWithLatitude:destCoord.latitude
                                                         longitude:destCoord.longitude];
        CLLocationDistance distance = [destLoc distanceFromLocation:sourceLoc];
        
        MKCoordinateRegion region = MKCoordinateRegionMakeWithDistance(midCoord, distance+100, distance+100);
        [self.mapView setRegion:region animated:YES];
        
        for (MKRoute *route in response.routes) {
            [self.mapView addOverlay:route.polyline level:MKOverlayLevelAboveRoads];
        }
    }];
}

- (MKOverlayRenderer *)mapView:(MKMapView *)mapView rendererForOverlay:(id<MKOverlay>)overlay
{
    if ([overlay isKindOfClass:[MKCircle class]]) {
        MKCircleRenderer *renderer = [[MKCircleRenderer alloc] initWithCircle:overlay];
        renderer.strokeColor = [UIColor colorWithRed:1.0 green:0.231 blue:0.188 alpha:1.0];
        return renderer;
    }
    else if ([overlay isKindOfClass:[MKPolyline class]]) {
        MKPolylineRenderer *renderer = [[MKPolylineRenderer alloc] initWithPolyline:overlay];
        renderer.strokeColor = [UIColor colorWithRed:0.0 green:0.478 blue:1.0 alpha:0.65];
        return renderer;
    }
    return nil;
}

@end
